==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ListenerFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ListenerFluentImpl<A extends ListenerFluent<A>> extends BaseFluent<A> implements ListenerFluent<A>{
  public ListenerFluentImpl() {
  }
  public ListenerFluentImpl(Listener instance) {
    this.withAllowedRoutes(instance.getAllowedRoutes()); 
    this.withHostname(instance.getHostname()); 
    this.withName(instance.getName()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withTls(instance.getTls()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private AllowedRoutesBuilder allowedRoutes;
  private String hostname;
  private String name;
  private Integer port;
  private String protocol;
  private GatewayTLSConfigBuilder tls;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAllowedRoutes instead.
   * @return The buildable object.
   */
  @Deprecated
  public AllowedRoutes getAllowedRoutes() {
    return this.allowedRoutes!=null ?this.allowedRoutes.build():null;
  }
  public AllowedRoutes buildAllowedRoutes() {
    return this.allowedRoutes!=null ?this.allowedRoutes.build():null;
  }
  public A withAllowedRoutes(AllowedRoutes allowedRoutes) {
    _visitables.get("allowedRoutes").remove(this.allowedRoutes);
    if (allowedRoutes!=null){ this.allowedRoutes= new AllowedRoutesBuilder(allowedRoutes); _visitables.get("allowedRoutes").add(this.allowedRoutes);} else { this.allowedRoutes = null; _visitables.get("allowedRoutes").remove(this.allowedRoutes); } return (A) this;
  }
  public Boolean hasAllowedRoutes() {
    return this.allowedRoutes != null;
  }
  public ListenerFluent.AllowedRoutesNested<A> withNewAllowedRoutes() {
    return new ListenerFluentImpl.AllowedRoutesNestedImpl();
  }
  public ListenerFluent.AllowedRoutesNested<A> withNewAllowedRoutesLike(AllowedRoutes item) {
    return new ListenerFluentImpl.AllowedRoutesNestedImpl(item);
  }
  public ListenerFluent.AllowedRoutesNested<A> editAllowedRoutes() {
    return withNewAllowedRoutesLike(getAllowedRoutes());
  }
  public ListenerFluent.AllowedRoutesNested<A> editOrNewAllowedRoutes() {
    return withNewAllowedRoutesLike(getAllowedRoutes() != null ? getAllowedRoutes(): new AllowedRoutesBuilder().build());
  }
  public ListenerFluent.AllowedRoutesNested<A> editOrNewAllowedRoutesLike(AllowedRoutes item) {
    return withNewAllowedRoutesLike(getAllowedRoutes() != null ? getAllowedRoutes(): item);
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public Boolean hasProtocol() {
    return this.protocol != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayTLSConfig getTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public GatewayTLSConfig buildTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public A withTls(GatewayTLSConfig tls) {
    _visitables.get("tls").remove(this.tls);
    if (tls!=null){ this.tls= new GatewayTLSConfigBuilder(tls); _visitables.get("tls").add(this.tls);} else { this.tls = null; _visitables.get("tls").remove(this.tls); } return (A) this;
  }
  public Boolean hasTls() {
    return this.tls != null;
  }
  public ListenerFluent.TlsNested<A> withNewTls() {
    return new ListenerFluentImpl.TlsNestedImpl();
  }
  public ListenerFluent.TlsNested<A> withNewTlsLike(GatewayTLSConfig item) {
    return new ListenerFluentImpl.TlsNestedImpl(item);
  }
  public ListenerFluent.TlsNested<A> editTls() {
    return withNewTlsLike(getTls());
  }
  public ListenerFluent.TlsNested<A> editOrNewTls() {
    return withNewTlsLike(getTls() != null ? getTls(): new GatewayTLSConfigBuilder().build());
  }
  public ListenerFluent.TlsNested<A> editOrNewTlsLike(GatewayTLSConfig item) {
    return withNewTlsLike(getTls() != null ? getTls(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ListenerFluentImpl that = (ListenerFluentImpl) o;
    if (allowedRoutes != null ? !allowedRoutes.equals(that.allowedRoutes) :that.allowedRoutes != null) return false;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (protocol != null ? !protocol.equals(that.protocol) :that.protocol != null) return false;
    if (tls != null ? !tls.equals(that.tls) :that.tls != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedRoutes,  hostname,  name,  port,  protocol,  tls,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allowedRoutes != null) { sb.append("allowedRoutes:"); sb.append(allowedRoutes + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (tls != null) { sb.append("tls:"); sb.append(tls + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AllowedRoutesNestedImpl<N> extends AllowedRoutesFluentImpl<ListenerFluent.AllowedRoutesNested<N>> implements ListenerFluent.AllowedRoutesNested<N>,Nested<N>{
    AllowedRoutesNestedImpl(AllowedRoutes item) {
      this.builder = new AllowedRoutesBuilder(this, item);
    }
    AllowedRoutesNestedImpl() {
      this.builder = new AllowedRoutesBuilder(this);
    }
    AllowedRoutesBuilder builder;
    public N and() {
      return (N) ListenerFluentImpl.this.withAllowedRoutes(builder.build());
    }
    public N endAllowedRoutes() {
      return and();
    }
    
  }
  class TlsNestedImpl<N> extends GatewayTLSConfigFluentImpl<ListenerFluent.TlsNested<N>> implements ListenerFluent.TlsNested<N>,Nested<N>{
    TlsNestedImpl(GatewayTLSConfig item) {
      this.builder = new GatewayTLSConfigBuilder(this, item);
    }
    TlsNestedImpl() {
      this.builder = new GatewayTLSConfigBuilder(this);
    }
    GatewayTLSConfigBuilder builder;
    public N and() {
      return (N) ListenerFluentImpl.this.withTls(builder.build());
    }
    public N endTls() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ListenerFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ListenerFluentImpl<A extends ListenerFluent<A>> extends BaseFluent<A> implements ListenerFluent<A>{
  public ListenerFluentImpl() {
  }
  public ListenerFluentImpl(Listener instance) {
    if (instance != null) {
      this.withAllowedRoutes(instance.getAllowedRoutes());
      this.withHostname(instance.getHostname());
      this.withName(instance.getName());
      this.withPort(instance.getPort());
      this.withProtocol(instance.getProtocol());
      this.withTls(instance.getTls());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private AllowedRoutesBuilder allowedRoutes;
  private String hostname;
  private String name;
  private Integer port;
  private String protocol;
  private GatewayTLSConfigBuilder tls;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAllowedRoutes instead.
   * @return The buildable object.
   */
  @Deprecated
  public AllowedRoutes getAllowedRoutes() {
    return this.allowedRoutes!=null ?this.allowedRoutes.build():null;
  }
  public AllowedRoutes buildAllowedRoutes() {
    return this.allowedRoutes!=null ?this.allowedRoutes.build():null;
  }
  public A withAllowedRoutes(AllowedRoutes allowedRoutes) {
    _visitables.get("allowedRoutes").remove(this.allowedRoutes);
    if (allowedRoutes!=null){ this.allowedRoutes= new AllowedRoutesBuilder(allowedRoutes); _visitables.get("allowedRoutes").add(this.allowedRoutes);} else { this.allowedRoutes = null; _visitables.get("allowedRoutes").remove(this.allowedRoutes); } return (A) this;
  }
  public Boolean hasAllowedRoutes() {
    return this.allowedRoutes != null;
  }
  public ListenerFluentImpl.AllowedRoutesNested<A> withNewAllowedRoutes() {
    return new ListenerFluentImpl.AllowedRoutesNestedImpl();
  }
  public ListenerFluentImpl.AllowedRoutesNested<A> withNewAllowedRoutesLike(AllowedRoutes item) {
    return new ListenerFluentImpl.AllowedRoutesNestedImpl(item);
  }
  public ListenerFluentImpl.AllowedRoutesNested<A> editAllowedRoutes() {
    return withNewAllowedRoutesLike(getAllowedRoutes());
  }
  public ListenerFluentImpl.AllowedRoutesNested<A> editOrNewAllowedRoutes() {
    return withNewAllowedRoutesLike(getAllowedRoutes() != null ? getAllowedRoutes(): new AllowedRoutesBuilder().build());
  }
  public ListenerFluentImpl.AllowedRoutesNested<A> editOrNewAllowedRoutesLike(AllowedRoutes item) {
    return withNewAllowedRoutesLike(getAllowedRoutes() != null ? getAllowedRoutes(): item);
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public Boolean hasProtocol() {
    return this.protocol != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayTLSConfig getTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public GatewayTLSConfig buildTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public A withTls(GatewayTLSConfig tls) {
    _visitables.get("tls").remove(this.tls);
    if (tls!=null){ this.tls= new GatewayTLSConfigBuilder(tls); _visitables.get("tls").add(this.tls);} else { this.tls = null; _visitables.get("tls").remove(this.tls); } return (A) this;
  }
  public Boolean hasTls() {
    return this.tls != null;
  }
  public ListenerFluentImpl.TlsNested<A> withNewTls() {
    return new ListenerFluentImpl.TlsNestedImpl();
  }
  public ListenerFluentImpl.TlsNested<A> withNewTlsLike(GatewayTLSConfig item) {
    return new ListenerFluentImpl.TlsNestedImpl(item);
  }
  public ListenerFluentImpl.TlsNested<A> editTls() {
    return withNewTlsLike(getTls());
  }
  public ListenerFluentImpl.TlsNested<A> editOrNewTls() {
    return withNewTlsLike(getTls() != null ? getTls(): new GatewayTLSConfigBuilder().build());
  }
  public ListenerFluentImpl.TlsNested<A> editOrNewTlsLike(GatewayTLSConfig item) {
    return withNewTlsLike(getTls() != null ? getTls(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ListenerFluentImpl that = (ListenerFluentImpl) o;
    if (!java.util.Objects.equals(allowedRoutes, that.allowedRoutes)) return false;

    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    if (!java.util.Objects.equals(protocol, that.protocol)) return false;

    if (!java.util.Objects.equals(tls, that.tls)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allowedRoutes,  hostname,  name,  port,  protocol,  tls,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allowedRoutes != null) { sb.append("allowedRoutes:"); sb.append(allowedRoutes + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (tls != null) { sb.append("tls:"); sb.append(tls + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class AllowedRoutesNestedImpl<N> extends AllowedRoutesFluentImpl<ListenerFluentImpl.AllowedRoutesNested<N>> implements ListenerFluentImpl.AllowedRoutesNested<N>,Nested<N>{
    AllowedRoutesNestedImpl(AllowedRoutes item) {
      this.builder = new AllowedRoutesBuilder(this, item);
    }
    AllowedRoutesNestedImpl() {
      this.builder = new AllowedRoutesBuilder(this);
    }
    AllowedRoutesBuilder builder;
    public N and() {
      return (N) ListenerFluentImpl.this.withAllowedRoutes(builder.build());
    }
    public N endAllowedRoutes() {
      return and();
    }
    
  }
  class TlsNestedImpl<N> extends GatewayTLSConfigFluentImpl<ListenerFluentImpl.TlsNested<N>> implements ListenerFluentImpl.TlsNested<N>,Nested<N>{
    TlsNestedImpl(GatewayTLSConfig item) {
      this.builder = new GatewayTLSConfigBuilder(this, item);
    }
    TlsNestedImpl() {
      this.builder = new GatewayTLSConfigBuilder(this);
    }
    GatewayTLSConfigBuilder builder;
    public N and() {
      return (N) ListenerFluentImpl.this.withTls(builder.build());
    }
    public N endTls() {
      return and();
    }
    
  }
  
}
